# Security Policy

Security is very important for pysswordSz. 🔒

Learn more about it below. 👇

## Versions

The latest versions of pysswordSz are supported.

## Reporting a Vulnerability

If you think you found a vulnerability, and even if you are not sure about it, please report it right away by sending an email to: zly@lyzhang.me . Please try to be as explicit as possible, describing all the steps and example code to reproduce the security issue.

I (the author, [@sidneyzhang](https://twitter.com/sidneyzhang)) will review it thoroughly and get back to you.

## Public Discussions

Please restrain from publicly discussing a potential security vulnerability. 🙊

It's better to discuss privately and try to find a solution first, to limit the potential impact as much as possible.

---

Thanks for your help!

I thank you for that. 🙇
